# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.interconnections_api import InterconnectionsApi


class TestInterconnectionsApi(unittest.TestCase):
    """InterconnectionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InterconnectionsApi()

    def tearDown(self) -> None:
        pass

    def test_create_interconnection_port_virtual_circuit(self) -> None:
        """Test case for create_interconnection_port_virtual_circuit

        Create a new Virtual Circuit
        """
        pass

    def test_create_organization_interconnection(self) -> None:
        """Test case for create_organization_interconnection

        Request a new interconnection for the organization
        """
        pass

    def test_create_project_interconnection(self) -> None:
        """Test case for create_project_interconnection

        Request a new interconnection for the project's organization
        """
        pass

    def test_delete_interconnection(self) -> None:
        """Test case for delete_interconnection

        Delete interconnection
        """
        pass

    def test_delete_virtual_circuit(self) -> None:
        """Test case for delete_virtual_circuit

        Delete a virtual circuit
        """
        pass

    def test_get_interconnection(self) -> None:
        """Test case for get_interconnection

        Get interconnection
        """
        pass

    def test_get_interconnection_metros(self) -> None:
        """Test case for get_interconnection_metros

        Get connectivity to network provider by metro
        """
        pass

    def test_get_interconnection_port(self) -> None:
        """Test case for get_interconnection_port

        Get a interconnection port
        """
        pass

    def test_get_interconnection_pricing(self) -> None:
        """Test case for get_interconnection_pricing

        Get Interconnection Pricing
        """
        pass

    def test_get_virtual_circuit(self) -> None:
        """Test case for get_virtual_circuit

        Get a virtual circuit
        """
        pass

    def test_list_interconnection_port_virtual_circuits(self) -> None:
        """Test case for list_interconnection_port_virtual_circuits

        List a interconnection port's virtual circuits
        """
        pass

    def test_list_interconnection_ports(self) -> None:
        """Test case for list_interconnection_ports

        List a interconnection's ports
        """
        pass

    def test_list_interconnection_virtual_circuits(self) -> None:
        """Test case for list_interconnection_virtual_circuits

        List a interconnection's virtual circuits
        """
        pass

    def test_organization_list_interconnections(self) -> None:
        """Test case for organization_list_interconnections

        List organization connections
        """
        pass

    def test_project_list_interconnections(self) -> None:
        """Test case for project_list_interconnections

        List project connections
        """
        pass

    def test_project_list_interconnections_all_pages(self):
        """Test case for project_list_interconnections_all_pages

        List project connections  # noqa: E501
        """
        pass

    def test_update_interconnection(self) -> None:
        """Test case for update_interconnection

        Update interconnection
        """
        pass

    def test_update_virtual_circuit(self) -> None:
        """Test case for update_virtual_circuit

        Update a virtual circuit
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_port import InterconnectionPort

class TestInterconnectionPort(unittest.TestCase):
    """InterconnectionPort unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionPort:
        """Test InterconnectionPort
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionPort`
        """
        model = InterconnectionPort()
        if include_optional:
            return InterconnectionPort(
                href = '',
                id = '',
                link_status = '',
                name = '',
                organization = equinix.services.metalv1.models.href.Href(
                    href = '', ),
                role = 'primary',
                speed = 56,
                status = 'requested',
                switch_id = '',
                virtual_circuits = [
                    null
                    ]
            )
        else:
            return InterconnectionPort(
        )
        """

    def testInterconnectionPort(self):
        """Test InterconnectionPort"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.interconnection_metro_list_metros_inner import InterconnectionMetroListMetrosInner

class TestInterconnectionMetroListMetrosInner(unittest.TestCase):
    """InterconnectionMetroListMetrosInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InterconnectionMetroListMetrosInner:
        """Test InterconnectionMetroListMetrosInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InterconnectionMetroListMetrosInner`
        """
        model = InterconnectionMetroListMetrosInner()
        if include_optional:
            return InterconnectionMetroListMetrosInner(
                code = '',
                country = '',
                href = '',
                id = '',
                name = '',
                providers = [
                    equinix.services.metalv1.models.interconnection_metro_list_metros_inner_all_of_providers_inner.InterconnectionMetroList_metros_inner_allOf_providers_inner(
                        bandwidths = [
                            50
                            ], 
                        features = [
                            'high capacity'
                            ], 
                        href = '', 
                        locations = [
                            'us-east-1'
                            ], 
                        name = 'AWS Direct Connect', 
                        type = 'CSP_AWS', )
                    ]
            )
        else:
            return InterconnectionMetroListMetrosInner(
        )
        """

    def testInterconnectionMetroListMetrosInner(self):
        """Test InterconnectionMetroListMetrosInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.price_search_response import PriceSearchResponse

class TestPriceSearchResponse(unittest.TestCase):
    """PriceSearchResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PriceSearchResponse:
        """Test PriceSearchResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PriceSearchResponse`
        """
        model = PriceSearchResponse()
        if include_optional:
            return PriceSearchResponse(
                data = [
                    equinix.services.fabricv4.models.price.Price(
                        href = '', 
                        type = 'VIRTUAL_CONNECTION_PRODUCT', 
                        code = '', 
                        name = '', 
                        description = '', 
                        account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                            account_number = 56, 
                            account_name = '', 
                            org_id = 56, 
                            organization_name = '', 
                            global_org_id = '', 
                            global_organization_name = '', 
                            ucm_id = '', 
                            global_cust_id = '', 
                            reseller_account_number = 56, 
                            reseller_account_name = '', 
                            reseller_ucm_id = '', 
                            reseller_org_id = 56, ), 
                        charges = [
                            equinix.services.fabricv4.models.price_charge.PriceCharge(
                                price = 0, )
                            ], 
                        currency = '', 
                        term_length = 12, 
                        catgory = 'COUNTRY', 
                        connection = equinix.services.fabricv4.models.virtual_connection_price.VirtualConnectionPrice(
                            uuid = '', 
                            bandwidth = 0, 
                            a_side = equinix.services.fabricv4.models.virtual_connection_price_a_side.VirtualConnectionPriceASide(
                                access_point = equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point.VirtualConnectionPriceASide_accessPoint(
                                    uuid = '', 
                                    location = equinix.services.fabricv4.models.price_location.PriceLocation(
                                        metro_code = '', 
                                        ibx = '', ), 
                                    port = equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port.VirtualConnectionPriceASide_accessPoint_port(
                                        settings = equinix.services.fabricv4.models.virtual_connection_price_a_side_access_point_port_settings.VirtualConnectionPriceASide_accessPoint_port_settings(
                                            buyout = True, ), ), ), ), 
                            z_side = equinix.services.fabricv4.models.virtual_connection_price_z_side.VirtualConnectionPriceZSide(), ), 
                        ip_block = equinix.services.fabricv4.models.ip_block_price.IpBlockPrice(
                            uuid = '', 
                            prefix_length = 56, ), 
                        router = equinix.services.fabricv4.models.fabric_cloud_router_price.FabricCloudRouterPrice(
                            uuid = '', 
                            package = equinix.services.fabricv4.models.fabric_cloud_router_packages.FabricCloudRouterPackages(
                                code = 'LAB', ), ), 
                        port = equinix.services.fabricv4.models.virtual_port_price.VirtualPortPrice(
                            uuid = '', 
                            lag = equinix.services.fabricv4.models.link_aggregation_group.LinkAggregationGroup(
                                enabled = True, ), 
                            physical_ports_quantity = 56, 
                            bandwidth = 56, 
                            redundancy = equinix.services.fabricv4.models.virtual_port_redundancy.VirtualPortRedundancy(
                                enabled = True, ), 
                            connectivity_source = equinix.services.fabricv4.models.connectivity_source.ConnectivitySource(), 
                            service_type = 'MSP', ), 
                        time_service = equinix.services.fabricv4.models.time_service_price.TimeServicePrice(), )
                    ],
                pagination = equinix.services.fabricv4.models.pagination.Pagination(
                    offset = 0, 
                    limit = 0, 
                    total = 0, 
                    next = '', 
                    previous = '', )
            )
        else:
            return PriceSearchResponse(
        )
        """

    def testPriceSearchResponse(self):
        """Test PriceSearchResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.api.cloud_routers_api import CloudRoutersApi


class TestCloudRoutersApi(unittest.TestCase):
    """CloudRoutersApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CloudRoutersApi()

    def tearDown(self) -> None:
        pass

    def test_create_cloud_router(self) -> None:
        """Test case for create_cloud_router

        Create Routers
        """
        pass

    def test_create_cloud_router_action(self) -> None:
        """Test case for create_cloud_router_action

        Create Route Table Action
        """
        pass

    def test_delete_cloud_router_by_uuid(self) -> None:
        """Test case for delete_cloud_router_by_uuid

        Delete Routers
        """
        pass

    def test_get_cloud_router_actions(self) -> None:
        """Test case for get_cloud_router_actions

        Get Route Table Actions
        """
        pass

    def test_get_cloud_router_actions_by_uuid(self) -> None:
        """Test case for get_cloud_router_actions_by_uuid

        Get Route Table Action by ID
        """
        pass

    def test_get_cloud_router_by_uuid(self) -> None:
        """Test case for get_cloud_router_by_uuid

        Get Routers
        """
        pass

    def test_get_cloud_router_package_by_code(self) -> None:
        """Test case for get_cloud_router_package_by_code

        Get Package Details
        """
        pass

    def test_get_cloud_router_packages(self) -> None:
        """Test case for get_cloud_router_packages

        List Packages
        """
        pass

    def test_search_cloud_router_routes(self) -> None:
        """Test case for search_cloud_router_routes

        Search Route Table
        """
        pass

    def test_search_cloud_routers(self) -> None:
        """Test case for search_cloud_routers

        Search Routers
        """
        pass

    def test_search_connection_advertised_routes(self) -> None:
        """Test case for search_connection_advertised_routes

        Search Advertised Routes
        """
        pass

    def test_search_connection_received_routes(self) -> None:
        """Test case for search_connection_received_routes

        Search Received Routes
        """
        pass

    def test_search_router_actions(self) -> None:
        """Test case for search_router_actions

        Search Route Table Actions
        """
        pass

    def test_update_cloud_router_by_uuid(self) -> None:
        """Test case for update_cloud_router_by_uuid

        Update Routers
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.connection_response import ConnectionResponse

class TestConnectionResponse(unittest.TestCase):
    """ConnectionResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ConnectionResponse:
        """Test ConnectionResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ConnectionResponse`
        """
        model = ConnectionResponse()
        if include_optional:
            return ConnectionResponse(
                additional_info = [
                    equinix.services.fabricv4.models.connection_side_additional_info.ConnectionSideAdditionalInfo(
                        key = '', 
                        value = '', )
                    ],
                data = [
                    equinix.services.fabricv4.models.validate_connection_response.ValidateConnectionResponse(
                        uuid = '', 
                        bandwidth = 0, 
                        redundancy = equinix.services.fabricv4.models.connection_redundancy.ConnectionRedundancy(
                            group = '', 
                            priority = 'PRIMARY', ), 
                        a_side = equinix.services.fabricv4.models.connection_side.ConnectionSide(
                            service_token = equinix.services.fabricv4.models.service_token.ServiceToken(
                                type = 'VC_TOKEN', 
                                href = '', 
                                expiry = 56, 
                                uuid = '', 
                                issuer_side = '', 
                                name = '', 
                                description = '', 
                                expiration_date_time = '2020-11-06T07:00Z', 
                                connection = equinix.services.fabricv4.models.service_token_connection.ServiceTokenConnection(
                                    type = 'EVPL_VC', 
                                    href = '', 
                                    uuid = '', 
                                    allow_remote_connection = True, 
                                    allow_custom_bandwidth = True, 
                                    bandwidth_limit = 0, 
                                    supported_bandwidths = [
                                        56
                                        ], 
                                    z_side = equinix.services.fabricv4.models.service_token_side.ServiceTokenSide(
                                        access_point_selectors = [
                                            equinix.services.fabricv4.models.access_point_selector.AccessPointSelector(
                                                hide_asset_info = True, 
                                                port = equinix.services.fabricv4.models.simplified_metadata_entity.SimplifiedMetadataEntity(
                                                    href = '', 
                                                    uuid = '', 
                                                    cvp_id = 56, 
                                                    bandwidth = 1.337, 
                                                    port_name = '', 
                                                    encapsulation_protocol_type = '', 
                                                    account_name = '', 
                                                    location = equinix.services.fabricv4.models.simplified_location.SimplifiedLocation(
                                                        metro_href = 'https://api.equinix.com/fabric/v4/metros/AM', 
                                                        region = 'AMER, APAC, EMEA', 
                                                        metro_name = 'Amsterdam', 
                                                        metro_code = 'AM', 
                                                        ibx = 'AM1', ), ), 
                                                link_protocol = equinix.services.fabricv4.models.simplified_link_protocol.SimplifiedLinkProtocol(
                                                    vlan_tag = 2, 
                                                    vlan_s_tag = 2, 
                                                    vlan_c_tag = 2, ), 
                                                virtual_device = equinix.services.fabricv4.models.simplified_virtual_device.SimplifiedVirtualDevice(
                                                    href = '', 
                                                    uuid = '', 
                                                    name = '', 
                                                    cluster = '', ), 
                                                interface = equinix.services.fabricv4.models.virtual_device_interface.VirtualDeviceInterface(
                                                    id = 56, 
                                                    uuid = '', ), 
                                                network = equinix.services.fabricv4.models.simplified_token_network.SimplifiedTokenNetwork(
                                                    href = '', 
                                                    uuid = '', 
                                                    name = '', 
                                                    scope = 'LOCAL', ), )
                                            ], ), ), 
                                state = 'ACTIVE', 
                                notifications = [
                                    equinix.services.fabricv4.models.simplified_notification.SimplifiedNotification(
                                        type = 'BANDWIDTH_ALERT', 
                                        send_interval = '', 
                                        emails = [
                                            ''
                                            ], 
                                        registered_users = [
                                            ''
                                            ], )
                                    ], 
                                account = equinix.services.fabricv4.models.simplified_account.SimplifiedAccount(
                                    account_number = 56, 
                                    account_name = '', 
                                    org_id = 56, 
                                    organization_name = '', 
                                    global_org_id = '', 
                                    global_organization_name = '', 
                                    ucm_id = '', 
                                    global_cust_id = '', 
                                    reseller_account_number = 56, 
                                    reseller_account_name = '', 
                                    reseller_ucm_id = '', 
                                    reseller_org_id = 56, ), 
                                changelog = equinix.services.fabricv4.models.changelog.Changelog(
                                    created_by = 'johnsmith', 
                                    created_by_full_name = 'John Smith', 
                                    created_by_email = 'john.smith@example.com', 
                                    created_date_time = '2020-11-06T07:00Z', 
                                    updated_by = 'johnsmith', 
                                    updated_by_full_name = 'John Smith', 
                                    updated_by_email = 'john.smith@example.com', 
                                    updated_date_time = '2020-11-06T07:00Z', 
                                    deleted_by = 'johnsmith', 
                                    deleted_by_full_name = 'John Smith', 
                                    deleted_by_email = 'john.smith@example.com', 
                                    deleted_date_time = '2020-11-06T07:00Z', ), 
                                project = equinix.services.fabricv4.models.project.Project(
                                    project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ), ), 
                            access_point = equinix.services.fabricv4.models.access_point.AccessPoint(
                                profile = equinix.services.fabricv4.models.simplified_service_profile.SimplifiedServiceProfile(
                                    href = '', 
                                    name = 'Sample Service Profile', 
                                    uuid = '', 
                                    description = 'offering connectivity to my-network', 
                                    tags = [
                                        ''
                                        ], 
                                    visibility = 'PRIVATE', 
                                    allowed_emails = [
                                        ''
                                        ], 
                                    access_point_type_configs = [
                                        equinix.services.fabricv4.models.service_profile_access_point_type.ServiceProfileAccessPointType()
                                        ], 
                                    custom_fields = [
                                        equinix.services.fabricv4.models.custom_field.CustomField(
                                            label = 'Account Number', 
                                            description = 'Provide a valid account number', 
                                            required = True, 
                                            data_type = 'STRING', 
                                            options = [
                                                ''
                                                ], 
                                            capture_in_email = True, )
                                        ], 
                                    marketing_info = equinix.services.fabricv4.models.marketing_info.MarketingInfo(
                                        logo = '', 
                                        promotion = True, 
                                        process_steps = [
                                            equinix.services.fabricv4.models.process_step.ProcessStep(
                                                title = '', 
                                                sub_title = '', 
                                                description = '', )
                                            ], ), 
                                    ports = [
                                        equinix.services.fabricv4.models.service_profile_access_point_colo.ServiceProfileAccessPointCOLO(
                                            type = 'XF_PORT', 
                                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                            seller_region = '', 
                                            seller_region_description = '', 
                                            cross_connect_id = '', )
                                        ], 
                                    virtual_devices = [
                                        equinix.services.fabricv4.models.service_profile_access_point_vd.ServiceProfileAccessPointVD(
                                            type = 'VD', 
                                            uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', 
                                            interface_uuid = '94662143-e21b-4098-bfcf-e9416f47eae1', )
                                        ], 
                                    metros = [
                                        equinix.services.fabricv4.models.service_metro.ServiceMetro(
                                            code = '', 
                                            name = '', 
                                            vc_bandwidth_max = 56, 
                                            ibxs = [
                                                ''
                                                ], 
                                            in_trail = True, 
                                            display_name = '', 
                                            seller_regions = {
                                                'key' : ''
                                                }, )
                                        ], 
                                    self_profile = True, 
                                    project_id = '', ), 
                                router = equinix.services.fabricv4.models.cloud_router.CloudRouter(
                                    href = 'https://api.equinix.com/fabric/v4/routers/3c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                                    uuid = 'c9b8e7a2-f3b1-4576-a4a9-1366a63df170', 
                                    name = 'test-fg-1', 
                                    equinix_asn = 30000, 
                                    connections_count = 0, 
                                    marketplace_subscription = equinix.services.fabricv4.models.marketplace_subscription.marketplaceSubscription(
                                        href = 'https://api.equinix.com/fabric/v4/marketplaceSubscriptions/20d32a80-0d61-4333-bc03-707b591ae2f5', 
                                        uuid = '20d32a80-0d61-4333-bc03-707b591ae2f5', ), 
                                    change_log = equinix.services.fabricv4.models.changelog.Changelog(
                                        created_by = 'johnsmith', 
                                        created_by_full_name = 'John Smith', 
                                        created_by_email = 'john.smith@example.com', 
                                        created_date_time = '2020-11-06T07:00Z', 
                                        updated_by = 'johnsmith', 
                                        updated_by_full_name = 'John Smith', 
                                        updated_by_email = 'john.smith@example.com', 
                                        updated_date_time = '2020-11-06T07:00Z', 
                                        deleted_by = 'johnsmith', 
                                        deleted_by_full_name = 'John Smith', 
                                        deleted_by_email = 'john.smith@example.com', 
                                        deleted_date_time = '2020-11-06T07:00Z', ), 
                                    change = equinix.services.fabricv4.models.cloud_router_change.CloudRouterChange(
                                        uuid = '', 
                                        type = 'ROUTER_UPDATE', 
                                        status = 'COMPLETED', 
                                        created_date_time = '2020-11-06T07:00Z', 
                                        updated_date_time = '2020-11-06T07:00Z', 
                                        information = '', 
                                        data = equinix.services.fabricv4.models.cloud_router_change_operation.CloudRouterChangeOperation(
                                            op = 'replace', 
                                            path = '', 
                                            value = equinix.services.fabricv4.models.value.value(), ), ), ), 
                                seller_region = '', 
                                peering_type = 'PRIVATE', 
                                authentication_key = '', 
                                provider_connection_id = '', 
                                virtual_network = equinix.services.fabricv4.models.virtual_network.VirtualNetwork(
                                    href = '', 
                                    uuid = '', ), 
                                interconnection = equinix.services.fabricv4.models.metal_interconnection.MetalInterconnection(
                                    uuid = '', ), 
                                vpic_interface = equinix.services.fabricv4.models.vpic_interface.VpicInterface(
                                    href = '', 
                                    uuid = '', ), ), 
                            internet_access = equinix.services.fabricv4.models.internet_access.InternetAccess(
                                uuid = '', ), 
                            company_profile = equinix.services.fabricv4.models.connection_company_profile.ConnectionCompanyProfile(
                                id = 1, 
                                name = 'Company-1', 
                                global_org_id = '', ), 
                            invitation = equinix.services.fabricv4.models.connection_invitation.ConnectionInvitation(
                                email = 'test@equinix.com', 
                                message = 'Hello, Please accept my invitation', 
                                ctr_draft_order_id = '', ), 
                            additional_info = [
                                equinix.services.fabricv4.models.connection_side_additional_info.ConnectionSideAdditionalInfo(
                                    key = '', 
                                    value = '', )
                                ], ), 
                        z_side = equinix.services.fabricv4.models.connection_side.ConnectionSide(), )
                    ]
            )
        else:
            return ConnectionResponse(
        )
        """

    def testConnectionResponse(self):
        """Test ConnectionResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class DedicatedPortCreateInput(BaseModel):
    """
    DedicatedPortCreateInput
    """ # noqa: E501
    billing_account_name: Optional[StrictStr] = Field(default=None, description="The billing account name of the Equinix Fabric account.")
    contact_email: Optional[StrictStr] = Field(default=None, description="The preferred email used for communication and notifications about the Equinix Fabric interconnection. Optional and defaults to the primary user email address when using a User API key or the organization owner email address when using a Project API key.")
    description: Optional[StrictStr] = None
    facility_id: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    metro: StrictStr = Field(description="A Metro ID or code. For interconnections with Dedicated Ports, this will be the location of the issued Dedicated Ports.")
    mode: Optional[StrictStr] = Field(default=None, description="The mode of the interconnection (only relevant to Dedicated Ports). Fabric VCs won't have this field. Can be either 'standard' or 'tunnel'.   The default mode of an interconnection on a Dedicated Port is 'standard'. The mode can only be changed when there are no associated virtual circuits on the interconnection.   In tunnel mode, an 802.1q tunnel is added to a port to send/receive double tagged packets from server instances.")
    name: StrictStr
    project: Optional[StrictStr] = None
    redundancy: StrictStr = Field(description="Either 'primary' or 'redundant'.")
    speed: Optional[StrictStr] = Field(default=None, description="A interconnection speed, in bps, mbps, or gbps. For Dedicated Ports, this can be 10Gbps or 100Gbps.")
    tags: Optional[List[StrictStr]] = None
    type: StrictStr = Field(description="When requesting for a dedicated port, the value of this field should be 'dedicated'.")
    use_case: Optional[StrictStr] = Field(default=None, description="The intended use case of the dedicated port.")
    __properties: ClassVar[List[str]] = ["billing_account_name", "contact_email", "description", "facility_id", "href", "metro", "mode", "name", "project", "redundancy", "speed", "tags", "type", "use_case"]

    @field_validator('mode')
    def mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['standard', 'tunnel']):
            raise ValueError("must be one of enum values ('standard', 'tunnel')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['dedicated']):
            raise ValueError("must be one of enum values ('dedicated')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of DedicatedPortCreateInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of DedicatedPortCreateInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "billing_account_name": obj.get("billing_account_name"),
            "contact_email": obj.get("contact_email"),
            "description": obj.get("description"),
            "facility_id": obj.get("facility_id"),
            "href": obj.get("href"),
            "metro": obj.get("metro"),
            "mode": obj.get("mode"),
            "name": obj.get("name"),
            "project": obj.get("project"),
            "redundancy": obj.get("redundancy"),
            "speed": obj.get("speed"),
            "tags": obj.get("tags"),
            "type": obj.get("type"),
            "use_case": obj.get("use_case")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.ssh_keys_api import SSHKeysApi


class TestSSHKeysApi(unittest.TestCase):
    """SSHKeysApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SSHKeysApi()

    def tearDown(self) -> None:
        pass

    def test_create_project_ssh_key(self) -> None:
        """Test case for create_project_ssh_key

        Create a ssh key for the given project
        """
        pass

    def test_create_ssh_key(self) -> None:
        """Test case for create_ssh_key

        Create a ssh key for the current user
        """
        pass

    def test_delete_ssh_key(self) -> None:
        """Test case for delete_ssh_key

        Delete the ssh key
        """
        pass

    def test_find_device_ssh_keys(self) -> None:
        """Test case for find_device_ssh_keys

        Retrieve a device's ssh keys
        """
        pass

    def test_find_project_ssh_keys(self) -> None:
        """Test case for find_project_ssh_keys

        Retrieve a project's ssh keys
        """
        pass

    def test_find_ssh_key_by_id(self) -> None:
        """Test case for find_ssh_key_by_id

        Retrieve a ssh key
        """
        pass

    def test_find_ssh_keys(self) -> None:
        """Test case for find_ssh_keys

        Retrieve all ssh keys
        """
        pass

    def test_update_ssh_key(self) -> None:
        """Test case for update_ssh_key

        Update the ssh key
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from equinix.services.metalv1.models.plan_available_in_inner import PlanAvailableInInner
from equinix.services.metalv1.models.plan_available_in_metros_inner import PlanAvailableInMetrosInner
from equinix.services.metalv1.models.plan_specs import PlanSpecs
from typing import Optional, Set
from typing_extensions import Self

class Plan(BaseModel):
    """
    Plan
    """ # noqa: E501
    available_in: Optional[List[PlanAvailableInInner]] = Field(default=None, description="Shows which facilities the plan is available in, and the facility-based price if it is different from the default price.")
    available_in_metros: Optional[List[PlanAvailableInMetrosInner]] = Field(default=None, description="Shows which metros the plan is available in, and the metro-based price if it is different from the default price.")
    categories: Optional[List[StrictStr]] = Field(default=None, description="Categories of the plan, like compute or storage. A Plan can belong to multiple categories.")
    var_class: Optional[StrictStr] = Field(default=None, alias="class")
    deployment_types: Optional[Annotated[List[StrictStr], Field(min_length=0)]] = None
    description: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    legacy: Optional[StrictBool] = Field(default=None, description="Deprecated. Always return false")
    line: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    pricing: Optional[Dict[str, Any]] = None
    slug: Optional[StrictStr] = None
    specs: Optional[PlanSpecs] = None
    type: Optional[StrictStr] = Field(default=None, description="The plan type")
    __properties: ClassVar[List[str]] = ["available_in", "available_in_metros", "categories", "class", "deployment_types", "description", "href", "id", "legacy", "line", "name", "pricing", "slug", "specs", "type"]

    @field_validator('deployment_types')
    def deployment_types_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['on_demand', 'spot_market']):
                raise ValueError("each list item must be one of ('on_demand', 'spot_market')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['standard', 'workload_optimized', 'custom']):
            raise ValueError("must be one of enum values ('standard', 'workload_optimized', 'custom')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Plan from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in available_in (list)
        _items = []
        if self.available_in:
            for _item in self.available_in:
                if _item:
                    _items.append(_item.to_dict())
            _dict['available_in'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in available_in_metros (list)
        _items = []
        if self.available_in_metros:
            for _item in self.available_in_metros:
                if _item:
                    _items.append(_item.to_dict())
            _dict['available_in_metros'] = _items
        # override the default output from pydantic by calling `to_dict()` of specs
        if self.specs:
            _dict['specs'] = self.specs.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Plan from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "available_in": [PlanAvailableInInner.from_dict(_item) for _item in obj["available_in"]] if obj.get("available_in") is not None else None,
            "available_in_metros": [PlanAvailableInMetrosInner.from_dict(_item) for _item in obj["available_in_metros"]] if obj.get("available_in_metros") is not None else None,
            "categories": obj.get("categories"),
            "class": obj.get("class"),
            "deployment_types": obj.get("deployment_types"),
            "description": obj.get("description"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "legacy": obj.get("legacy"),
            "line": obj.get("line"),
            "name": obj.get("name"),
            "pricing": obj.get("pricing"),
            "slug": obj.get("slug"),
            "specs": PlanSpecs.from_dict(obj["specs"]) if obj.get("specs") is not None else None,
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.spot_prices_per_facility import SpotPricesPerFacility

class TestSpotPricesPerFacility(unittest.TestCase):
    """SpotPricesPerFacility unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpotPricesPerFacility:
        """Test SpotPricesPerFacility
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpotPricesPerFacility`
        """
        model = SpotPricesPerFacility()
        if include_optional:
            return SpotPricesPerFacility(
                baremetal_0 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_1 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2a = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_2a2 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_3 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                baremetal_s = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                c2_medium_x86 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, ),
                href = '',
                m2_xlarge_x86 = equinix.services.metalv1.models.spot_prices_per_baremetal.SpotPricesPerBaremetal(
                    href = '', 
                    price = 1.337, )
            )
        else:
            return SpotPricesPerFacility(
        )
        """

    def testSpotPricesPerFacility(self):
        """Test SpotPricesPerFacility"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class NetworkSearchFieldName(str, Enum):
    """
    Possible field names to use on filters
    """

    """
    allowed enum values
    """
    SLASH_NAME = '/name'
    SLASH_UUID = '/uuid'
    SLASH_SCOPE = '/scope'
    SLASH_TYPE = '/type'
    SLASH_OPERATION_SLASH_EQUINIX_STATUS = '/operation/equinixStatus'
    SLASH_LOCATION_SLASH_REGION = '/location/region'
    SLASH_PROJECT_SLASH_PROJECT_ID = '/project/projectId'
    SLASH_ACCOUNT_SLASH_GLOBAL_CUST_ID = '/account/globalCustId'
    SLASH_ACCOUNT_SLASH_ORG_ID = '/account/orgId'
    SLASH_DELETED_DATE = '/deletedDate'
    SLASH_STAR = '/*'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of NetworkSearchFieldName from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.href import Href
from equinix.services.metalv1.models.ip_reservation_facility import IPReservationFacility
from equinix.services.metalv1.models.ip_reservation_metro import IPReservationMetro
from equinix.services.metalv1.models.metal_gateway_lite import MetalGatewayLite
from equinix.services.metalv1.models.project import Project
from typing import Optional, Set
from typing_extensions import Self

class IPReservation(BaseModel):
    """
    IPReservation
    """ # noqa: E501
    addon: Optional[StrictBool] = None
    address: Optional[StrictStr] = None
    address_family: Optional[StrictInt] = None
    assignments: Optional[List[Href]] = None
    available: Optional[StrictStr] = None
    bill: Optional[StrictBool] = None
    cidr: Optional[StrictInt] = None
    created_at: Optional[datetime] = None
    customdata: Optional[Dict[str, Any]] = None
    details: Optional[StrictStr] = None
    enabled: Optional[StrictBool] = None
    facility: Optional[IPReservationFacility] = None
    gateway: Optional[StrictStr] = None
    global_ip: Optional[StrictBool] = None
    href: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    manageable: Optional[StrictBool] = None
    management: Optional[StrictBool] = None
    metal_gateway: Optional[MetalGatewayLite] = None
    metro: Optional[IPReservationMetro] = None
    netmask: Optional[StrictStr] = None
    network: Optional[StrictStr] = None
    project: Optional[Project] = None
    project_lite: Optional[Href] = None
    public: Optional[StrictBool] = None
    requested_by: Optional[Href] = None
    state: Optional[StrictStr] = None
    tags: Optional[List[StrictStr]] = None
    type: StrictStr
    __properties: ClassVar[List[str]] = ["addon", "address", "address_family", "assignments", "available", "bill", "cidr", "created_at", "customdata", "details", "enabled", "facility", "gateway", "global_ip", "href", "id", "manageable", "management", "metal_gateway", "metro", "netmask", "network", "project", "project_lite", "public", "requested_by", "state", "tags", "type"]

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['global_ipv4', 'public_ipv4', 'private_ipv4', 'public_ipv6']):
            raise ValueError("must be one of enum values ('global_ipv4', 'public_ipv4', 'private_ipv4', 'public_ipv6')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of IPReservation from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in assignments (list)
        _items = []
        if self.assignments:
            for _item in self.assignments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['assignments'] = _items
        # override the default output from pydantic by calling `to_dict()` of facility
        if self.facility:
            _dict['facility'] = self.facility.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metal_gateway
        if self.metal_gateway:
            _dict['metal_gateway'] = self.metal_gateway.to_dict()
        # override the default output from pydantic by calling `to_dict()` of metro
        if self.metro:
            _dict['metro'] = self.metro.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project_lite
        if self.project_lite:
            _dict['project_lite'] = self.project_lite.to_dict()
        # override the default output from pydantic by calling `to_dict()` of requested_by
        if self.requested_by:
            _dict['requested_by'] = self.requested_by.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of IPReservation from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "addon": obj.get("addon"),
            "address": obj.get("address"),
            "address_family": obj.get("address_family"),
            "assignments": [Href.from_dict(_item) for _item in obj["assignments"]] if obj.get("assignments") is not None else None,
            "available": obj.get("available"),
            "bill": obj.get("bill"),
            "cidr": obj.get("cidr"),
            "created_at": obj.get("created_at"),
            "customdata": obj.get("customdata"),
            "details": obj.get("details"),
            "enabled": obj.get("enabled"),
            "facility": IPReservationFacility.from_dict(obj["facility"]) if obj.get("facility") is not None else None,
            "gateway": obj.get("gateway"),
            "global_ip": obj.get("global_ip"),
            "href": obj.get("href"),
            "id": obj.get("id"),
            "manageable": obj.get("manageable"),
            "management": obj.get("management"),
            "metal_gateway": MetalGatewayLite.from_dict(obj["metal_gateway"]) if obj.get("metal_gateway") is not None else None,
            "metro": IPReservationMetro.from_dict(obj["metro"]) if obj.get("metro") is not None else None,
            "netmask": obj.get("netmask"),
            "network": obj.get("network"),
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "project_lite": Href.from_dict(obj["project_lite"]) if obj.get("project_lite") is not None else None,
            "public": obj.get("public"),
            "requested_by": Href.from_dict(obj["requested_by"]) if obj.get("requested_by") is not None else None,
            "state": obj.get("state"),
            "tags": obj.get("tags"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import date
from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.metalv1.models.line_item_adjustment import LineItemAdjustment
from equinix.services.metalv1.models.plan_id_name import PlanIdName
from equinix.services.metalv1.models.project_id_name import ProjectIdName
from typing import Optional, Set
from typing_extensions import Self

class LineItem(BaseModel):
    """
    LineItem
    """ # noqa: E501
    adjustments: Optional[List[LineItemAdjustment]] = Field(default=None, description="Adjustments for the line item")
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    currency: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    details: Optional[StrictStr] = None
    end_date: Optional[date] = None
    hostname: Optional[StrictStr] = None
    href: Optional[StrictStr] = None
    item_type: Optional[StrictStr] = None
    location: Optional[StrictStr] = None
    plan: Optional[PlanIdName] = None
    plan_id: Optional[StrictStr] = None
    project: Optional[ProjectIdName] = None
    project_id: Optional[StrictStr] = None
    service_id: Optional[StrictStr] = None
    start_date: Optional[date] = None
    unit: Optional[StrictStr] = None
    unit_price: Optional[Union[StrictFloat, StrictInt]] = None
    __properties: ClassVar[List[str]] = ["adjustments", "amount", "currency", "description", "details", "end_date", "hostname", "href", "item_type", "location", "plan", "plan_id", "project", "project_id", "service_id", "start_date", "unit", "unit_price"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of LineItem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in adjustments (list)
        _items = []
        if self.adjustments:
            for _item in self.adjustments:
                if _item:
                    _items.append(_item.to_dict())
            _dict['adjustments'] = _items
        # override the default output from pydantic by calling `to_dict()` of plan
        if self.plan:
            _dict['plan'] = self.plan.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of LineItem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "adjustments": [LineItemAdjustment.from_dict(_item) for _item in obj["adjustments"]] if obj.get("adjustments") is not None else None,
            "amount": obj.get("amount"),
            "currency": obj.get("currency"),
            "description": obj.get("description"),
            "details": obj.get("details"),
            "end_date": obj.get("end_date"),
            "hostname": obj.get("hostname"),
            "href": obj.get("href"),
            "item_type": obj.get("item_type"),
            "location": obj.get("location"),
            "plan": PlanIdName.from_dict(obj["plan"]) if obj.get("plan") is not None else None,
            "plan_id": obj.get("plan_id"),
            "project": ProjectIdName.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "project_id": obj.get("project_id"),
            "service_id": obj.get("service_id"),
            "start_date": obj.get("start_date"),
            "unit": obj.get("unit"),
            "unit_price": obj.get("unit_price")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.fabricv4.models.stream_subscription_post_request import StreamSubscriptionPostRequest

class TestStreamSubscriptionPostRequest(unittest.TestCase):
    """StreamSubscriptionPostRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StreamSubscriptionPostRequest:
        """Test StreamSubscriptionPostRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StreamSubscriptionPostRequest`
        """
        model = StreamSubscriptionPostRequest()
        if include_optional:
            return StreamSubscriptionPostRequest(
                type = 'STREAM_SUBSCRIPTION',
                name = '',
                description = '',
                project = equinix.services.fabricv4.models.project.Project(
                    project_id = '44f4c4f8-2f39-494e-838c-d8e640591be5', ),
                enabled = True,
                stream = equinix.services.fabricv4.models.stream_target.StreamTarget(
                    uuid = '657400f8-d360-11e9-bb65-2a2ae2dbcce5', ),
                filters = equinix.services.fabricv4.models.stream_subscription_filter.StreamSubscriptionFilter(
                    and = [
                        equinix.services.fabricv4.models.stream_filter.StreamFilter()
                        ], ),
                metric_selector = equinix.services.fabricv4.models.stream_subscription_selector.StreamSubscriptionSelector(
                    include = [
                        'equinix.fabric.connection.*'
                        ], 
                    except = [
                        'equinix.fabric.connection.*'
                        ], ),
                event_selector = equinix.services.fabricv4.models.stream_subscription_selector.StreamSubscriptionSelector(
                    include = [
                        'equinix.fabric.connection.*'
                        ], 
                    except = [
                        'equinix.fabric.connection.*'
                        ], ),
                sink = equinix.services.fabricv4.models.stream_subscription_sink.StreamSubscriptionSink(
                    uri = '', 
                    type = 'DATADOG', 
                    batch_enabled = False, 
                    batch_size_max = 56, 
                    batch_wait_time_max = 56, 
                    credential = equinix.services.fabricv4.models.stream_subscription_sink_credential.StreamSubscriptionSinkCredential(
                        access_token = '', 
                        integration_key = '', 
                        api_key = '', ), 
                    settings = equinix.services.fabricv4.models.stream_subscription_sink_setting.StreamSubscriptionSinkSetting(
                        event_index = '', 
                        metric_index = '', 
                        source = '', 
                        application_key = '', ), )
            )
        else:
            return StreamSubscriptionPostRequest(
        )
        """

    def testStreamSubscriptionPostRequest(self):
        """Test StreamSubscriptionPostRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.organizations_api import OrganizationsApi


class TestOrganizationsApi(unittest.TestCase):
    """OrganizationsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OrganizationsApi()

    def tearDown(self) -> None:
        pass

    def test_create_organization(self) -> None:
        """Test case for create_organization

        Create an organization
        """
        pass

    def test_create_organization_invitation(self) -> None:
        """Test case for create_organization_invitation

        Create an invitation for an organization
        """
        pass

    def test_create_organization_project(self) -> None:
        """Test case for create_organization_project

        Create a project for the organization
        """
        pass

    def test_create_payment_method(self) -> None:
        """Test case for create_payment_method

        Create a payment method for the given organization
        """
        pass

    def test_delete_organization(self) -> None:
        """Test case for delete_organization

        Delete the organization
        """
        pass

    def test_find_operating_systems_by_organization(self) -> None:
        """Test case for find_operating_systems_by_organization

        Retrieve all operating systems visible by the organization
        """
        pass

    def test_find_organization_by_id(self) -> None:
        """Test case for find_organization_by_id

        Retrieve an organization's details
        """
        pass

    def test_find_organization_customdata(self) -> None:
        """Test case for find_organization_customdata

        Retrieve the custom metadata of an organization
        """
        pass

    def test_find_organization_invitations(self) -> None:
        """Test case for find_organization_invitations

        Retrieve organization invitations
        """
        pass

    def test_find_organization_payment_methods(self) -> None:
        """Test case for find_organization_payment_methods

        Retrieve all payment methods of an organization
        """
        pass

    def test_find_organization_projects(self) -> None:
        """Test case for find_organization_projects

        Retrieve all projects of an organization
        """
        pass

    def test_find_organization_projects_all_pages(self):
        """Test case for find_organization_projects_all_pages

        Retrieve all projects of an organization  # noqa: E501
        """
        pass

    def test_find_organization_transfers(self) -> None:
        """Test case for find_organization_transfers

        Retrieve all project transfer requests from or to an organization
        """
        pass

    def test_find_organizations(self) -> None:
        """Test case for find_organizations

        Retrieve all organizations
        """
        pass

    def test_find_organizations_all_pages(self):
        """Test case for find_organizations_all_pages

        Retrieve all organizations  # noqa: E501
        """
        pass

    def test_find_plans_by_organization(self) -> None:
        """Test case for find_plans_by_organization

        Retrieve all plans visible by the organization
        """
        pass

    def test_update_organization(self) -> None:
        """Test case for update_organization

        Update the organization
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.authentication_api import AuthenticationApi


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AuthenticationApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key(self) -> None:
        """Test case for create_api_key

        Create an API key
        """
        pass

    def test_create_project_api_key(self) -> None:
        """Test case for create_project_api_key

        Create an API key for a project.
        """
        pass

    def test_delete_api_key(self) -> None:
        """Test case for delete_api_key

        Delete the API key
        """
        pass

    def test_delete_user_api_key(self) -> None:
        """Test case for delete_user_api_key

        Delete the API key
        """
        pass

    def test_find_api_keys(self) -> None:
        """Test case for find_api_keys

        Retrieve all user API keys
        """
        pass

    def test_find_project_api_keys(self) -> None:
        """Test case for find_project_api_keys

        Retrieve all API keys for the project.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
from inspect import getfullargspec
import json
import pprint
import re  # noqa: F401
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Optional
from equinix.services.fabricv4.models.cloud_router_actions_search_expression import CloudRouterActionsSearchExpression
from equinix.services.fabricv4.models.cloud_router_actions_search_or_filter import CloudRouterActionsSearchOrFilter
from typing import Union, Any, List, TYPE_CHECKING, Optional, Dict
from typing_extensions import Literal, Self
from pydantic import Field

CLOUDROUTERACTIONSSEARCHFILTER_ANY_OF_SCHEMAS = ["CloudRouterActionsSearchExpression", "CloudRouterActionsSearchOrFilter"]

class CloudRouterActionsSearchFilter(BaseModel):
    """
    CloudRouterActionsSearchFilter
    """

    # data type: CloudRouterActionsSearchExpression
    anyof_schema_1_validator: Optional[CloudRouterActionsSearchExpression] = None
    # data type: CloudRouterActionsSearchOrFilter
    anyof_schema_2_validator: Optional[CloudRouterActionsSearchOrFilter] = None
    if TYPE_CHECKING:
        actual_instance: Optional[Union[CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter]] = None
    else:
        actual_instance: Any = None
    any_of_schemas: List[str] = Field(default=Literal["CloudRouterActionsSearchExpression", "CloudRouterActionsSearchOrFilter"])

    model_config = {
        "validate_assignment": True,
        "protected_namespaces": (),
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_anyof(cls, v):
        instance = CloudRouterActionsSearchFilter.model_construct()
        error_messages = []
        # validate data type: CloudRouterActionsSearchExpression
        if not isinstance(v, CloudRouterActionsSearchExpression):
            error_messages.append(f"Error! Input type `{type(v)}` is not `CloudRouterActionsSearchExpression`")
        else:
            return v

        # validate data type: CloudRouterActionsSearchOrFilter
        if not isinstance(v, CloudRouterActionsSearchOrFilter):
            error_messages.append(f"Error! Input type `{type(v)}` is not `CloudRouterActionsSearchOrFilter`")
        else:
            return v

        if error_messages:
            # no match
            raise ValueError("No match found when setting the actual_instance in CloudRouterActionsSearchFilter with anyOf schemas: CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Dict[str, Any]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        # anyof_schema_1_validator: Optional[CloudRouterActionsSearchExpression] = None
        try:
            instance.actual_instance = CloudRouterActionsSearchExpression.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))
        # anyof_schema_2_validator: Optional[CloudRouterActionsSearchOrFilter] = None
        try:
            instance.actual_instance = CloudRouterActionsSearchOrFilter.from_json(json_str)
            return instance
        except (ValidationError, ValueError) as e:
             error_messages.append(str(e))

        if error_messages:
            # no match
            raise ValueError("No match found when deserializing the JSON string into CloudRouterActionsSearchFilter with anyOf schemas: CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], CloudRouterActionsSearchExpression, CloudRouterActionsSearchOrFilter]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.plan_list import PlanList

class TestPlanList(unittest.TestCase):
    """PlanList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PlanList:
        """Test PlanList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PlanList`
        """
        model = PlanList()
        if include_optional:
            return PlanList(
                href = '',
                plans = [
                    equinix.services.metalv1.models.plan.Plan(
                        available_in = [
                            equinix.services.metalv1.models.plan_available_in_inner.Plan_available_in_inner(
                                href = '', 
                                price = equinix.services.metalv1.models.plan_available_in_inner_price.Plan_available_in_inner_price(
                                    hour = 1.23, 
                                    href = '', ), )
                            ], 
                        available_in_metros = [
                            equinix.services.metalv1.models.plan_available_in_metros_inner.Plan_available_in_metros_inner(
                                href = '', )
                            ], 
                        categories = [
                            ''
                            ], 
                        class = 'm3.large.x86', 
                        deployment_types = [
                            'on_demand'
                            ], 
                        description = '', 
                        href = '', 
                        id = '', 
                        legacy = True, 
                        line = '', 
                        name = '', 
                        pricing = equinix.services.metalv1.models.pricing.pricing(), 
                        slug = 'm3.large.x86', 
                        specs = equinix.services.metalv1.models.plan_specs.Plan_specs(
                            cpus = [
                                equinix.services.metalv1.models.plan_specs_cpus_inner.Plan_specs_cpus_inner(
                                    count = 56, 
                                    href = '', 
                                    type = '', )
                                ], 
                            drives = [
                                equinix.services.metalv1.models.plan_specs_drives_inner.Plan_specs_drives_inner(
                                    category = '', 
                                    count = 56, 
                                    href = '', 
                                    size = '3.84TB', 
                                    type = '', )
                                ], 
                            features = equinix.services.metalv1.models.plan_specs_features.Plan_specs_features(
                                href = '', 
                                raid = True, 
                                txt = True, 
                                uefi = True, ), 
                            href = '', 
                            memory = equinix.services.metalv1.models.plan_specs_memory.Plan_specs_memory(
                                href = '', 
                                total = '', ), 
                            nics = [
                                equinix.services.metalv1.models.plan_specs_nics_inner.Plan_specs_nics_inner(
                                    count = 2, 
                                    href = '', 
                                    type = '', )
                                ], ), 
                        type = 'standard', )
                    ]
            )
        else:
            return PlanList(
        )
        """

    def testPlanList(self):
        """Test PlanList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
